==> haskell-configfile-1.1.4-85-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ConfigFile
version:              1.1.4
visibility:           public
id:                   ConfigFile-1.1.4-GDFPeDGsJtEGcRqivBejyS
key:                  ConfigFile-1.1.4-GDFPeDGsJtEGcRqivBejyS
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2014 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Stable
homepage:             http://software.complete.org/configfile
synopsis:             Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.

    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.

    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.

category:             Parsing
abi:                  9ca55bc71a435fe3d00b13d49b071f99
exposed:              True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types

hidden-modules:       Data.ConfigFile.Lexer
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ConfigFile-1.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configfile
hs-libraries:         HSConfigFile-1.1.4-GDFPeDGsJtEGcRqivBejyS
depends:
    MissingH-1.6.0.1-ANBYcBEscAD1PDyDLu2Ez1 base-4.16.4.0
    containers-0.6.5.1 mtl-2.2.2 parsec-3.1.15.0

haddock-interfaces:   /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html:         /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-88-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ConfigFile
version:              1.1.4
visibility:           public
id:                   ConfigFile-1.1.4-6yBMwoXR9i9G93aUrBatSX
key:                  ConfigFile-1.1.4-6yBMwoXR9i9G93aUrBatSX
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2014 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Stable
homepage:             http://software.complete.org/configfile
synopsis:             Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.

    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.

    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.

category:             Parsing
abi:                  6c278ca94cd935d2455360de06e9761a
exposed:              True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types

hidden-modules:       Data.ConfigFile.Lexer
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ConfigFile-1.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configfile
hs-libraries:         HSConfigFile-1.1.4-6yBMwoXR9i9G93aUrBatSX
depends:
    MissingH-1.6.0.1-JFwuvmnCGPgICA7pqFbybB base-4.16.4.0
    containers-0.6.5.1 mtl-2.2.2 parsec-3.1.15.0

haddock-interfaces:   /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html:         /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
